% Auto-generated chapter 18 for malik
% Hadiths in this chapter: 59

\hadithdefcmd{malik}{630}{حَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، عَنْ نَافِعٍ، عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم ذَكَرَ رَمَضَانَ فَقَالَ ‏ "‏ لاَ تَصُومُوا حَتَّى تَرَوُا الْهِلاَلَ وَلاَ تُفْطِرُوا حَتَّى تَرَوْهُ فَإِنْ غُمَّ عَلَيْكُمْ فَاقْدُرُوا لَهُ ‏"‏ ‏.‏\hadithno{630}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me that Malik had seen that the people of knowledge used to like to pay the zakat al-fitr after dawn had broken on the day of the Fitr before they went to the place of prayer. Malik said, "There is leeway in this, if Allah wills, in that it can be paid either before setting out (for the prayer) on the day of Fitr or afterwards." Yahya related to me that Malik said, "A man does not have to pay zakat for the slaves of his slaves, or for some one employed by him, or for his wife's slaves, except for anyone who serves him and whose services are indispensable to him, in which case he must pay zakat. He does not have to pay zakat for any of his slaves that are kafir and have not become muslim, whether they be for trade or otherwise." Yahya related to me from Malik from Nafi from Abdullah ibn Umar that the Messenger of Allah, may Allah bless him and grant him peace, once mentioned Ramadan and said, "Do not begin the fast until you see the new moon, and do not break the fast (at the end of Ramadan) until you see it. If the new moon is obscured from you, then work out (when it should be)}}
\hadithdefcmd{malik}{631}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ عَبْدِ اللَّهِ بْنِ دِينَارٍ، عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ الشَّهْرُ تِسْعٌ وَعِشْرُونَ فَلاَ تَصُومُوا حَتَّى تَرَوُا الْهِلاَلَ وَلاَ تُفْطِرُوا حَتَّى تَرَوْهُ فَإِنْ غُمَّ عَلَيْكُمْ فَاقْدُرُوا لَهُ ‏"‏ ‏.‏\hadithno{631}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Abdullah ibn Dinar from Abdullah ibn Umar that the Messenger of Allah, may Allah bless him and grant him peace, said, "A month has twenty-nine days in it. Do not start the fast or break it until you see the new moon. If the new moon is obscured from you, then work out (when it should be)}}
\hadithdefcmd{malik}{632}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ ثَوْرِ بْنِ زَيْدٍ الدِّيلِيِّ، عَنْ عَبْدِ اللَّهِ بْنِ عَبَّاسٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم ذَكَرَ رَمَضَانَ فَقَالَ ‏ "‏ لاَ تَصُومُوا حَتَّى تَرَوُا الْهِلاَلَ وَلاَ تُفْطِرُوا حَتَّى تَرَوْهُ فَإِنْ غُمَّ عَلَيْكُمْ فَأَكْمِلُوا الْعِدَّةَ ثَلاَثِينَ ‏"‏ ‏.‏\hadithno{632}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Thawr ibn Zayd ad-Dili from Abdullah ibn Abbas that the Messenger of Allah, may Allah bless him and grant him peace, once mentioned Ramadan and said, "Do not start the fast or break it until you see the new moon. If the new moon is obscured from you, then complete a full thirty days}}
\hadithdefcmd{malik}{633}{وَحَدَّثَنِي عَنْ مَالِكٍ، أَنَّهُ بَلَغَهُ أَنَّ الْهِلاَلَ، رُئِيَ فِي زَمَانِ عُثْمَانَ بْنِ عَفَّانَ بِعَشِيٍّ فَلَمْ يُفْطِرْ عُثْمَانُ حَتَّى أَمْسَى وَغَابَتِ الشَّمْسُ ‏.‏ قَالَ يَحْيَى سَمِعْتُ مَالِكًا يَقُولُ فِي الَّذِي يَرَى هِلاَلَ رَمَضَانَ وَحْدَهُ أَنَّهُ يَصُومُ لاَ يَنْبَغِي لَهُ أَنْ يُفْطِرَ وَهُوَ يَعْلَمُ أَنَّ ذَلِكَ الْيَوْمَ مِنْ رَمَضَانَ ‏.‏ قَالَ وَمَنْ رَأَى هِلاَلَ شَوَّالٍ وَحْدَهُ فَإِنَّهُ لاَ يُفْطِرُ لأَنَّ النَّاسَ يَتَّهِمُونَ عَلَى أَنْ يُفْطِرَ مِنْهُمْ مَنْ لَيْسَ مَأْمُونًا وَيَقُولُ أُولَئِكَ إِذَا ظَهَرَ عَلَيْهِمْ قَدْ رَأَيْنَا الْهِلاَلَ وَمَنْ رَأَى هِلاَلَ شَوَّالٍ نَهَارًا فَلاَ يُفْطِرْ وَيُتِمُّ صِيَامَ يَوْمِهِ ذَلِكَ فَإِنَّمَا هُوَ هِلاَلُ اللَّيْلَةِ الَّتِي تَأْتِي ‏.‏ قَالَ يَحْيَى وَسَمِعْتُ مَالِكًا يَقُولُ إِذَا صَامَ النَّاسُ يَوْمَ الْفِطْرِ - وَهُمْ يَظُنُّونَ أَنَّهُ مِنْ رَمَضَانَ - فَجَاءَهُمْ ثَبَتٌ أَنَّ هِلاَلَ رَمَضَانَ قَدْ رُئِيَ قَبْلَ أَنْ يَصُومُوا بِيَوْمٍ وَأَنَّ يَوْمَهُمْ ذَلِكَ أَحَدٌ وَثَلاَثُونَ فَإِنَّهُمْ يُفْطِرُونَ فِي ذَلِكَ الْيَوْمِ أَيَّةَ سَاعَةٍ جَاءَهُمُ الْخَبَرُ غَيْرَ أَنَّهُمْ لاَ يُصَلُّونَ صَلاَةَ الْعِيدِ إِنْ كَانَ ذَلِكَ جَاءَهُمْ بَعْدَ زَوَالِ الشَّمْسِ ‏.‏\hadithno{633}\hadithgrade{Salim al-Hilali: Mauquf Daif}\hadithtrans{Yahya related to me from Malik that he had heard that once in the time of Uthman ibn Affan the new moon had been seen in the afternoon and Uthman did not break his fast until evening had come and the sun had set. Yahya said that he had heard Malik say that some one who sees the new moon of Ramadan when he is on his own should start the fast and not break it if he knows that that day is part of Ramadan. He added, "Some one who sees the new moon of Shawwal when he is on his own does not break the fast, because people suspect the reliability of someone among them who breaks the fast. Such people should say, when they sight the new moon, 'We have seen the new moon.' Whoever sees the new moon of Shawwal during the day should not break his fast but should continue fasting for the rest of that day. This is because it is really the new moon of the night that is coming ." Yahya said that he heard Malik say, "If people are fasting on the day of Fitr thinking that it is still Ramadan and then definite evidence comes to them that the new moon of Ramadan had been seen one day before they began to fast and that they are now into the thirty- first day, then they should break the fast on that day at whatever time the news comes to them. However, they do not pray the id prayer if they hear the news after the sun has begun to decline}}
\hadithdefcmd{malik}{634}{حَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، عَنْ نَافِعٍ، عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ، أَنَّهُ كَانَ يَقُولُ لاَ يَصُومُ إِلاَّ مَنْ أَجْمَعَ الصِّيَامَ قَبْلَ الْفَجْرِ ‏.‏\hadithno{634}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Yahya related to me from Malik from Nafi that Abdullah ibn Umar used to say, "Only some one who makes the intention to fast before dawn (actually) fasts}}
\hadithdefcmd{malik}{635}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنِ ابْنِ شِهَابٍ، عَنْ عَائِشَةَ، وَحَفْصَةَ، زَوْجَىِ النَّبِيِّ صلى الله عليه وسلم بِمِثْلِ ذَلِكَ ‏.‏\hadithno{635}\hadithgrade{Salim al-Hilali: Mauquf Daif}\hadithtrans{Yahya related to me from Malik from Ibn Shihab that A'isha and Hafsa, the wives of the Prophet, may Allah bless him and grant him peace, also said that}}
\hadithdefcmd{malik}{636}{حَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، عَنْ أَبِي حَازِمِ بْنِ دِينَارٍ، عَنْ سَهْلِ بْنِ سَعْدٍ السَّاعِدِيِّ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ يَزَالُ النَّاسُ بِخَيْرٍ مَا عَجَّلُوا الْفِطْرَ ‏"‏ ‏.‏\hadithno{636}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Abu Hazim ibn Dinar from Sahl ibn Sad as Saidi that the Messenger of Allah, may Allah bless him and grant him peace, said, "People will remain in good as long as they are quick to break the fast}}
\hadithdefcmd{malik}{637}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ حَرْمَلَةَ الأَسْلَمِيِّ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ يَزَالُ النَّاسُ بِخَيْرٍ مَا عَجَّلُوا الْفِطْرَ ‏"‏ ‏.‏\hadithno{637}\hadithgrade{Salim al-Hilali: Hasan}\hadithtrans{Yahya related to me from Malik from Abd ar-Rahman ibn Harmala al- Aslami from Said ibn al-Musayyab that the Messenger of Allah, may Allah bless him and grant him peace, said, "People will remain in good as long as they are quick to break the fast}}
\hadithdefcmd{malik}{638}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنِ ابْنِ شِهَابٍ، عَنْ حُمَيْدِ بْنِ عَبْدِ الرَّحْمَنِ، أَنَّ عُمَرَ بْنَ الْخَطَّابِ، وَعُثْمَانَ بْنَ عَفَّانَ، كَانَا يُصَلِّيَانِ الْمَغْرِبَ حِينَ يَنْظُرَانِ إِلَى اللَّيْلِ الأَسْوَدِ قَبْلَ أَنْ يُفْطِرَا ثُمَّ يُفْطِرَانِ بَعْدَ الصَّلاَةِ وَذَلِكَ فِي رَمَضَانَ ‏.‏\hadithno{638}\hadithgrade{Salim al-Hilali: Mauquf Daif}\hadithtrans{Yahya related to me from Malik from Ibn Shihab from Humayd ibn Abd ar-Rahman that Umar ibn al-Khattab and Uthman ibn Affan would pray maghrib when they saw the night darkening, before they broke their fast, and that was during Ramadan}}
\hadithdefcmd{malik}{639}{حَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، عَنْ عَبْدِ اللَّهِ بْنِ عَبْدِ الرَّحْمَنِ بْنِ مَعْمَرٍ الأَنْصَارِيِّ، عَنْ أَبِي يُونُسَ، مَوْلَى عَائِشَةَ عَنْ عَائِشَةَ، أَنَّ رَجُلاً، قَالَ لِرَسُولِ اللَّهِ صلى الله عليه وسلم وَهُوَ وَاقِفٌ عَلَى الْبَابِ وَأَنَا أَسْمَعُ يَا رَسُولَ اللَّهِ إِنِّي أُصْبِحُ جُنُبًا وَأَنَا أُرِيدُ الصِّيَامَ ‏.‏ فَقَالَ صلى الله عليه وسلم ‏"‏ وَأَنَا أُصْبِحُ جُنُبًا وَأَنَا أُرِيدُ الصِّيَامَ فَأَغْتَسِلُ وَأَصُومُ ‏"‏ ‏.‏ فَقَالَ لَهُ الرَّجُلُ يَا رَسُولَ اللَّهِ إِنَّكَ لَسْتَ مِثْلَنَا قَدْ غَفَرَ اللَّهُ لَكَ مَا تَقَدَّمَ مِنْ ذَنْبِكَ وَمَا تَأَخَّرَ ‏.‏ فَغَضِبَ رَسُولُ اللَّهِ صلى الله عليه وسلم وَقَالَ ‏"‏ وَاللَّهِ إِنِّي لأَرْجُو أَنْ أَكُونَ أَخْشَاكُمْ لِلَّهِ وَأَعْلَمَكُمْ بِمَا أَتَّقِي ‏"‏ ‏.‏\hadithno{639}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Abdullah ibn Abd ar-Rahman ibn Mamar al-Ansari from Abu Yunus, the mawla of A'isha, from A'isha that she overheard a man standing at the door saying to the Messenger of Allah, may Allah bless him and grant him peace, "Messenger of Allah, I get up in the morning junub, in a state of major ritual impurity, and want to fast," and the Messenger of Allah, may Allah bless him and grant him peace, said, "I too get up in the morning junub and want to fast, so I do ghusl and fast." The man said to him, "You are not the same as us. Allah has forgiven you all your wrong actions that have gone before and those that have come after." The Messenger of Allah, may Allah bless him and grant him peace, got angry and said, "By Allah, I hope that I am the most fearful of you with respect to Allah and the most knowledgeable of you in how I have taqwa}}
\hadithdefcmd{malik}{640}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ عَبْدِ رَبِّهِ بْنِ سَعِيدٍ، عَنْ أَبِي بَكْرِ بْنِ عَبْدِ الرَّحْمَنِ بْنِ الْحَارِثِ بْنِ هِشَامٍ، عَنْ عَائِشَةَ، وَأُمِّ سَلَمَةَ زَوْجَىِ النَّبِيِّ صلى الله عليه وسلم أَنَّهُمَا قَالَتَا كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يُصْبِحُ جُنُبًا مِنْ جِمَاعٍ غَيْرِ احْتِلاَمٍ فِي رَمَضَانَ ثُمَّ يَصُومُ ‏.‏\hadithno{640}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Abd Rabbih ibn Said from Abu Bakr ibn Abd ar-Rahman ibn al-Harith ibn Hisham from A'isha and Umm Salama, the wives of the Prophet, may Allah bless him and grant him peace, that the Prophet, may Allah bless him and grant him peace, used to get up in the morning junub from intercourse, not a dream, in Ramadan, and then he would fast}}
\hadithdefcmd{malik}{641}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ سُمَىٍّ، مَوْلَى أَبِي بَكْرِ بْنِ عَبْدِ الرَّحْمَنِ بْنِ الْحَارِثِ بْنِ هِشَامٍ أَنَّهُ سَمِعَ أَبَا بَكْرِ بْنَ عَبْدِ الرَّحْمَنِ بْنِ الْحَارِثِ بْنِ هِشَامٍ، يَقُولُ كُنْتُ أَنَا وَأَبِي، عِنْدَ مَرْوَانَ بْنِ الْحَكَمِ - وَهُوَ أَمِيرُ الْمَدِينَةِ - فَذُكِرَ لَهُ أَنَّ أَبَا هُرَيْرَةَ يَقُولُ مَنْ أَصْبَحَ جُنُبًا أَفْطَرَ ذَلِكَ الْيَوْمَ ‏.‏ فَقَالَ مَرْوَانُ أَقْسَمْتُ عَلَيْكَ يَا عَبْدَ الرَّحْمَنِ لَتَذْهَبَنَّ إِلَى أُمَّىِ الْمُؤْمِنِينَ عَائِشَةَ وَأُمِّ سَلَمَةَ فَلَتَسْأَلَنَّهُمَا عَنْ ذَلِكَ فَذَهَبَ عَبْدُ الرَّحْمَنِ وَذَهَبْتُ مَعَهُ حَتَّى دَخَلْنَا عَلَى عَائِشَةَ فَسَلَّمَ عَلَيْهَا ثُمَّ قَالَ يَا أُمَّ الْمُؤْمِنِينَ إِنَّا كُنَّا عِنْدَ مَرْوَانَ بْنِ الْحَكَمِ فَذُكِرَ لَهُ أَنَّ أَبَا هُرَيْرَةَ يَقُولُ مَنْ أَصْبَحَ جُنُبًا أَفْطَرَ ذَلِكَ الْيَوْمَ ‏.‏ قَالَتْ عَائِشَةُ لَيْسَ كَمَا قَالَ أَبُو هُرَيْرَةَ يَا عَبْدَ الرَّحْمَنِ أَتَرْغَبُ عَمَّا كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَصْنَعُ فَقَالَ عَبْدُ الرَّحْمَنِ لاَ وَاللَّهِ ‏.‏ قَالَتْ عَائِشَةُ فَأَشْهَدُ عَلَى رَسُولِ اللَّهِ صلى الله عليه وسلم أَنَّهُ كَانَ يُصْبِحُ جُنُبًا مِنْ جِمَاعٍ غَيْرِ احْتِلاَمٍ ثُمَّ يَصُومُ ذَلِكَ الْيَوْمَ ‏.‏ قَالَ ثُمَّ خَرَجْنَا حَتَّى دَخَلْنَا عَلَى أُمِّ سَلَمَةَ فَسَأَلَهَا عَنْ ذَلِكَ فَقَالَتْ مِثْلَ مَا قَالَتْ عَائِشَةُ ‏.‏ قَالَ فَخَرَجْنَا حَتَّى جِئْنَا مَرْوَانَ بْنَ الْحَكَمِ فَذَكَرَ لَهُ عَبْدُ الرَّحْمَنِ مَا قَالَتَا فَقَالَ مَرْوَانُ أَقْسَمْتُ عَلَيْكَ يَا أَبَا مُحَمَّدٍ لَتَرْكَبَنَّ دَابَّتِي فَإِنَّهَا بِالْبَابِ فَلْتَذْهَبَنَّ إِلَى أَبِي هُرَيْرَةَ فَإِنَّهُ بِأَرْضِهِ بِالْعَقِيقِ فَلْتُخْبِرَنَّهُ ذَلِكَ ‏.‏ فَرَكِبَ عَبْدُ الرَّحْمَنِ وَرَكِبْتُ مَعَهُ حَتَّى أَتَيْنَا أَبَا هُرَيْرَةَ فَتَحَدَّثَ مَعَهُ عَبْدُ الرَّحْمَنِ سَاعَةً ثُمَّ ذَكَرَ لَهُ ذَلِكَ فَقَالَ لَهُ أَبُو هُرَيْرَةَ لاَ عِلْمَ لِي بِذَاكَ إِنَّمَا أَخْبَرَنِيهِ مُخْبِرٌ ‏.‏\hadithno{641}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Sumayy, the mawla of Abu Bakr ibn Abd ar-Rahman ibn al-Harith ibn Hisham that he heard Abu Bakr ibn Abd ar-Rahman ibn al-Harith ibn Hisham say, "My father and I were with Marwan ibn al Hakam at the time when he was amir of Madina, and someone mentioned to him that Abu Hurayra used to say, 'If someone begins the morning junub, he has broken the fast for that day.' Marwan said, 'I swear to you, Abdar-Rahman, you must go to the two umm al muminin, A'isha and Umm Salama, and ask them about it.' ''Abd ar-Rahman went to visit A'isha and I accompanied him. He greeted her and then said, 'Umm al-muminin, we were with Marwan ibn al Hakam and someone mentioned to him that Abu Hurayra used to say that if some one had begun the morning junub, he had broken the fast for that day.' A'isha said, 'It is not as Abu Hurayra says Abd ar-Rahman. Do you dislike what the Messenger of Allah, may Allah bless him and grant him peace, used to do?', and Abd ar-Rahman said, 'No, by Allah.' A'isha said, 'I bear witness that the Messenger of Allah, may Allah bless him and grant him peace, used to get up in the morning junub from intercourse, not a dream, and would then fast for that day.' " He continued, "Then we went and visited Umm Salama, and Abd ar- Rahman asked her about the same matter and she said the same as A'isha had said. Then we went off until we came to Marwan ibn al-Hakam Abd ar-Rahman told him what they had both said and Marwan said, 'I swear to you, Abu Muhammad, you must use the mount which is at the door, and go to Abu Hurayra, who is on his land at al Aqiq, and tell him this.' So Abd ar-Rahman rode off, and I went with him, until we came to Abu Hurayra. Abd ar-Rahman talked with him for a while, and then mentioned the matter to him, and Abu Hurayra said, 'I don't know anything about it. I was just told that by someone}}
\hadithdefcmd{malik}{642}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ سُمَىٍّ، مَوْلَى أَبِي بَكْرٍ عَنْ أَبِي بَكْرِ بْنِ عَبْدِ الرَّحْمَنِ، عَنْ عَائِشَةَ، وَأُمِّ سَلَمَةَ زَوْجَىِ النَّبِيِّ صلى الله عليه وسلم أَنَّهُمَا قَالَتَا إِنْ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم لَيُصْبِحُ جُنُبًا مِنْ جِمَاعٍ غَيْرِ احْتِلاَمٍ ثُمَّ يَصُومُ ‏.‏\hadithno{642}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Sumayy, the mawla of Abu Bakr, from Abu Bakr ibn Abd ar-Rahman that A'isha and Umm Salama, the wives of the Prophet, may Allah bless him and grant him peace, said, "The Messengerof Allah, may Allah bless him and grant him peace, used to get up in the morning junub from intercourse, not a dream, and would then fast}}
\hadithdefcmd{malik}{643}{حَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، عَنْ زَيْدِ بْنِ أَسْلَمَ، عَنْ عَطَاءِ بْنِ يَسَارٍ، أَنَّ رَجُلاً، قَبَّلَ امْرَأَتَهُ وَهُوَ صَائِمٌ فِي رَمَضَانَ فَوَجَدَ مِنْ ذَلِكَ وَجْدًا شَدِيدًا فَأَرْسَلَ امْرَأَتَهُ تَسْأَلُ لَهُ عَنْ ذَلِكَ فَدَخَلَتْ عَلَى أُمِّ سَلَمَةَ زَوْجِ النَّبِيِّ صلى الله عليه وسلم فَذَكَرَتْ ذَلِكَ لَهَا فَأَخْبَرَتْهَا أُمُّ سَلَمَةَ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم يُقَبِّلُ وَهُوَ صَائِمٌ فَرَجَعَتْ فَأَخْبَرَتْ زَوْجَهَا بِذَلِكَ فَزَادَهُ ذَلِكَ شَرًّا وَقَالَ لَسْنَا مِثْلَ رَسُولِ اللَّهِ صلى الله عليه وسلم اللَّهُ يُحِلُّ لِرَسُولِ اللَّهِ صلى الله عليه وسلم مَا شَاءَ ‏.‏ ثُمَّ رَجَعَتِ امْرَأَتُهُ إِلَى أُمِّ سَلَمَةَ فَوَجَدَتْ عِنْدَهَا رَسُولَ اللَّهِ صلى الله عليه وسلم فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ مَا لِهَذِهِ الْمَرْأَةِ ‏"‏ ‏.‏ فَأَخْبَرَتْهُ أُمُّ سَلَمَةَ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ أَلاَّ أَخْبَرْتِيهَا أَنِّي أَفْعَلُ ذَلِكَ ‏"‏ ‏.‏ فَقَالَتْ قَدْ أَخْبَرْتُهَا فَذَهَبَتْ إِلَى زَوْجِهَا فَأَخْبَرَتْهُ فَزَادَهُ ذَلِكَ شَرًّا وَقَالَ لَسْنَا مِثْلَ رَسُولِ اللَّهِ صلى الله عليه وسلم اللَّهُ يُحِلُّ لِرَسُولِهِ صلى الله عليه وسلم مَا شَاءَ ‏.‏ فَغَضِبَ رَسُولُ اللَّهِ صلى الله عليه وسلم وَقَالَ ‏"‏ وَاللَّهِ إِنِّي لأَتْقَاكُمْ لِلَّهِ وَأَعْلَمُكُمْ بِحُدُودِهِ ‏"‏ ‏.‏\hadithno{643}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Zayd ibn Aslam from Ata ibn Yasar that a certain man kissed his wife while he was fasting in Ramadan. This made him very anxious, and so he sent his wife to the Prophet, may Allah bless him and grant him peace, to ask him about that for him. She went in and saw Umm Salama, the wife of the Prophet, may Allah bless him and grant him peace, and mentioned the matter to her, and Umm Salama told her that the Messenger of Allah, may Allah bless him and grant him peace, used to kiss while he was fasting. So she went back and told her husband that, but it only made him find fault all the more and he said, "We are not like the Messenger of Allah, may Allah bless him and grant him peace. Allah makes permissible for the Messenger of Allah, may Allah bless him and grant him peace, whatever He wishes." His wife then went back to Umm Salama and found the Messenger of Allah, may Allah bless him and grant him peace, with her. The Messenger of Allah, may Allah bless him and grant him peace, said, "What's the matter with this woman?", and Umm Salama told him. The Messenger of Allah, may Allah bless him and grant him peace, said, "Didn't you tell her that I do that myself?" and she said, "I told her, and she went to her husband and told him, but it only made him find fault all the more and say, 'We are not like the Messenger of Allah, may Allah bless him and grant him peace. Allah makes permissible for His Messenger, may Allah bless him and grant him peace, whatever He wishes.' " The Messenger of Allah, may Allah bless him and grant him peace, got angry and said, "By Allah, I am the one with the most taqwa of Allah of you all, and of you all the one who best knows His limits}}
\hadithdefcmd{malik}{644}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ أُمِّ الْمُؤْمِنِينَ، - رضى الله عنها - أَنَّهَا قَالَتْ إِنْ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم لَيُقَبِّلُ بَعْضَ أَزْوَاجِهِ وَهُوَ صَائِمٌ ‏.‏ ثُمَّ ضَحِكَتْ ‏.‏\hadithno{644}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Hisham ibn Urwa from his father that A'isha, umm al-muminin, may Allah be pleased with her, said, "The Messenger of Allah, may Allah bless him and grant him peace, used to kiss certain of his wives when fasting," and then she laughed}}
\hadithdefcmd{malik}{645}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ يَحْيَى بْنِ سَعِيدٍ، أَنَّ عَاتِكَةَ ابْنَةَ زَيْدِ بْنِ عَمْرِو بْنِ نُفَيْلٍ، - امْرَأَةَ عُمَرَ بْنِ الْخَطَّابِ - كَانَتْ تُقَبِّلُ رَأْسَ عُمَرَ بْنِ الْخَطَّابِ وَهُوَ صَائِمٌ فَلاَ يَنْهَاهَا ‏.‏\hadithno{645}\hadithgrade{Salim al-Hilali: Mauquf Daif}\hadithtrans{Yahya related to me from Malik from Yahya ibn Said that Atika bint Zayd ibn Amr ibn Nufayl, the wife of Umar ibn al-Khattab, used to kiss Umar ibn al-Khattab's head while he was fasting, and he did not tell her not to}}
\hadithdefcmd{malik}{646}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ أَبِي النَّضْرِ، مَوْلَى عُمَرَ بْنِ عُبَيْدِ اللَّهِ أَنَّ عَائِشَةَ بِنْتَ طَلْحَةَ، أَخْبَرَتْهُ أَنَّهَا، كَانَتْ عِنْدَ عَائِشَةَ زَوْجِ النَّبِيِّ صلى الله عليه وسلم فَدَخَلَ عَلَيْهَا زَوْجُهَا هُنَالِكَ وَهُوَ عَبْدُ اللَّهِ بْنُ عَبْدِ الرَّحْمَنِ بْنِ أَبِي بَكْرٍ الصِّدِّيقِ وَهُوَ صَائِمٌ فَقَالَتْ لَهُ عَائِشَةُ مَا يَمْنَعُكَ أَنْ تَدْنُوَ مِنْ أَهْلِكَ فَتُقَبِّلَهَا وَتُلاَعِبَهَا فَقَالَ أُقَبِّلُهَا وَأَنَا صَائِمٌ قَالَتْ نَعَمْ ‏.‏\hadithno{646}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Yahya related to me from Malik from Abu'n-Nadr, the mawla of Umar ibn Ubaydullah that A'isha bint Talha told him that she was once with A'isha, the wife of the Prophet, may Allah bless him and grant him peace, and her husband, who was fasting, came and visited her there. (He was Abdullah ibn Abd ar-Rahman ibn Abi Bakras-Siddiq.) A'isha said to him, "What's stopping you from coming close to your wife and kissing her and joking with her?" He said, "Can I kiss her when I am fasting?" She said, "Yes}}
\hadithdefcmd{malik}{647}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ زَيْدِ بْنِ أَسْلَمَ، أَنَّ أَبَا هُرَيْرَةَ، وَسَعْدَ بْنَ أَبِي وَقَّاصٍ، كَانَا يُرَخِّصَانِ فِي الْقُبْلَةِ لِلصَّائِمِ ‏.‏\hadithno{647}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Yahya related to me from Malik from Zayd ibn Aslam that Abu Hurayra and Sad ibn Abi Waqqas used to say that someone who was fasting was allowed to kiss}}
\hadithdefcmd{malik}{648}{حَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، أَنَّهُ بَلَغَهُ أَنَّ عَائِشَةَ، زَوْجَ النَّبِيِّ صلى الله عليه وسلم كَانَتْ إِذَا ذَكَرَتْ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم يُقَبِّلُ وَهُوَ صَائِمٌ تَقُولُ وَأَيُّكُمْ أَمْلَكُ لِنَفْسِهِ مِنْ رَسُولِ اللَّهِ صلى الله عليه وسلم\hadithno{648}\hadithgrade{Salim al-Hilali: Maqtu Sahih}\hadithtrans{Yahya related to me from Malik that he had heard that A'isha, the wife of the Prophet, may Allah bless him and grant him peace, would say, when she mentioned that the Messenger of Allah, used to kiss while fasting, "And who among you is more able to control himself than the Messenger of Allah, may Allah bless him and grant him peace?}}
\hadithdefcmd{malik}{649}{قَالَ يَحْيَى قَالَ مَالِكٌ قَالَ هِشَامُ بْنُ عُرْوَةَ قَالَ عُرْوَةُ بْنُ الزُّبَيْرِ لَمْ أَرَ الْقُبْلَةَ لِلصَّائِمِ تَدْعُو إِلَى خَيْرٍ ‏.‏\hadithno{649}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Yahya said that Malik said that Hisham ibn Urwa ibn az-Zubayr had said, "I do not think that kissing invites to good for people who are fasting}}
\hadithdefcmd{malik}{650}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ زَيْدِ بْنِ أَسْلَمَ، عَنْ عَطَاءِ بْنِ يَسَارٍ، أَنَّ عَبْدَ اللَّهِ بْنَ عَبَّاسٍ، سُئِلَ عَنِ الْقُبْلَةِ، لِلصَّائِمِ فَأَرْخَصَ فِيهَا لِلشَّيْخِ وَكَرِهَهَا لِلشَّابِّ ‏.‏\hadithno{650}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Yahya related to me from Malik from Zayd ibn Aslam from Ata ibn Yasar that Abdullah ibn Abbas was asked about people kissing while fasting and he said that he allowed it for old men but disapproved of it for young men}}
\hadithdefcmd{malik}{651}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ نَافِعٍ، أَنَّ عَبْدَ اللَّهِ بْنَ عُمَرَ، كَانَ يَنْهَى عَنِ الْقُبْلَةِ، وَالْمُبَاشَرَةِ، لِلصَّائِمِ ‏.‏\hadithno{651}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Nafi that Abdullah ibn Umar used to forbid kissing and fondling for people who were fasting}}
\hadithdefcmd{malik}{652}{حَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، عَنِ ابْنِ شِهَابٍ، عَنْ عُبَيْدِ اللَّهِ بْنِ عَبْدِ اللَّهِ بْنِ عُتْبَةَ بْنِ مَسْعُودٍ، عَنْ عَبْدِ اللَّهِ بْنِ عَبَّاسٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم خَرَجَ إِلَى مَكَّةَ عَامَ الْفَتْحِ فِي رَمَضَانَ فَصَامَ حَتَّى بَلَغَ الْكَدِيدَ ثُمَّ أَفْطَرَ فَأَفْطَرَ النَّاسُ وَكَانُوا يَأْخُذُونَ بِالأَحْدَثِ فَالأَحْدَثِ مِنْ أَمْرِ رَسُولِ اللَّهِ صلى الله عليه وسلم ‏.‏\hadithno{652}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Ibn Shihab from Ubaydullah ibn Abdullah ibn Utba ibn Masud from Abdullah ibn Abbas that the Messenger of Allah, may Allah bless him and grant him peace, left for Makka in Ramadan during the year of the conquest, and fasted until he reached al-Kadid. He then broke the fast, and so everyone else did so as well. What people used to do was act according to whatever the Messenger of Allah, may Allah bless him and grant him peace, had done most recently}}
\hadithdefcmd{malik}{653}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ سُمَىٍّ، مَوْلَى أَبِي بَكْرِ بْنِ عَبْدِ الرَّحْمَنِ عَنْ أَبِي بَكْرِ بْنِ عَبْدِ الرَّحْمَنِ، عَنْ بَعْضِ، أَصْحَابِ رَسُولِ اللَّهِ صلى الله عليه وسلم أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم أَمَرَ النَّاسَ فِي سَفَرِهِ عَامَ الْفَتْحِ بِالْفِطْرِ وَقَالَ ‏ "‏ تَقَوَّوْا لِعَدُوِّكُمْ ‏"‏ ‏.‏ وَصَامَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏.‏ قَالَ أَبُو بَكْرٍ قَالَ الَّذِي حَدَّثَنِي لَقَدْ رَأَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم بِالْعَرْجِ يَصُبُّ الْمَاءَ عَلَى رَأْسِهِ مِنَ الْعَطَشِ أَوْ مِنَ الْحَرِّ ثُمَّ قِيلَ لِرَسُولِ اللَّهِ صلى الله عليه وسلم يَا رَسُولَ اللَّهِ إِنَّ طَائِفَةً مِنَ النَّاسِ قَدْ صَامُوا حِينَ صُمْتَ - قَالَ - فَلَمَّا كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم بِالْكَدِيدِ دَعَا بِقَدَحٍ فَشَرِبَ فَأَفْطَرَ النَّاسُ ‏.‏\hadithno{653}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Sumayy, the mawla of Abu Bakr ibn Abd ar-Rahman, from Abu Bakr ibn Abd ar-Rahman from one of the companions of the Messenger of Allah, that the Messenger of Allah, may Allah bless him and grant him peace, ordered everyone to break the fast on the journey he made in the year of the conquest saying, "Be strong for your enemy," while the Messenger of Allah, may Allah bless him and grant him peace, kept on fasting. Abu Bakr said that the one who related this to him said, "I saw the Messenger of Allah, may Allah bless him and grant him peace, pouring water over his head at al-Arj, either from thirst or from the heat. Then some one said to the Messenger of Allah, may Allah bless him and grant him peace, 'Messenger of Allah, a group of people kept on fasting when you did.' Then when the Messenger of Allah was at al-Kadid, he asked for a drinking-bowl and drank, and everyone broke the fast}}
\hadithdefcmd{malik}{654}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ حُمَيْدٍ الطَّوِيلِ، عَنْ أَنَسِ بْنِ مَالِكٍ، أَنَّهُ قَالَ سَافَرْنَا مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم فِي رَمَضَانَ فَلَمْ يَعِبِ الصَّائِمُ عَلَى الْمُفْطِرِ وَلاَ الْمُفْطِرُ عَلَى الصَّائِمِ ‏.‏\hadithno{654}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Humayd at-Tawil that Anas ibn Malik said, "We once travelled with the Messenger of Allah, may Allah bless him and grant him peace, in Ramadan, and those who were fasting did not find fault with those who were not, and those who were not fasting did not find fault with those who were}}
\hadithdefcmd{malik}{655}{وَحَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، أَنَّ حَمْزَةَ بْنَ عَمْرٍو الأَسْلَمِيَّ، قَالَ لِرَسُولِ اللَّهِ صلى الله عليه وسلم يَا رَسُولَ اللَّهِ إِنِّي رَجُلٌ أَصُومُ أَفَأَصُومُ فِي السَّفَرِ فَقَالَ لَهُ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِنْ شِئْتَ فَصُمْ وَإِنْ شِئْتَ فَأَفْطِرْ ‏"‏ ‏.‏\hadithno{655}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Hisham ibn Urwa from his father that Hamza ibn Amr al-Aslami once said to the Messenger of Allah, may Allah bless him and grant him peace, "Messenger of Allah, I am a man who fasts. Can I fast when travelling?" The Messenger of Allah, may Allah bless him and grant him peace, said, "If you want you can fast, and if you want you can break the fast}}
\hadithdefcmd{malik}{656}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ نَافِعٍ، أَنَّ عَبْدَ اللَّهِ بْنَ عُمَرَ، كَانَ لاَ يَصُومُ فِي السَّفَرِ ‏.‏\hadithno{656}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Yahya related to me from Malik from Nafi that Abdullah ibn Umar used not to fast while travelling}}
\hadithdefcmd{malik}{657}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، أَنَّهُ كَانَ يُسَافِرُ فِي رَمَضَانَ وَنُسَافِرُ مَعَهُ فَيَصُومُ عُرْوَةُ وَنُفْطِرُ نَحْنُ فَلاَ يَأْمُرُنَا بِالصِّيَامِ ‏.‏\hadithno{657}\hadithgrade{Salim al-Hilali: Maqtu Sahih}\hadithtrans{Yahya related to me from Malik that Hisham ibn Urwa said, "My father, Urwa, used to travel in Ramadan, and we would travel with him, and he used to fast while we would break the fast, and he would not tell us to fast}}
\hadithdefcmd{malik}{658}{حَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، أَنَّهُ بَلَغَهُ أَنَّ عُمَرَ بْنَ الْخَطَّابِ، كَانَ إِذَا كَانَ فِي سَفَرٍ فِي رَمَضَانَ فَعَلِمَ أَنَّهُ دَاخِلٌ الْمَدِينَةَ مِنْ أَوَّلِ يَوْمِهِ دَخَلَ وَهُوَ صَائِمٌ ‏.‏ قَالَ يَحْيَى قَالَ مَالِكٌ مَنْ كَانَ فِي سَفَرٍ فَعَلِمَ أَنَّهُ دَاخِلٌ عَلَى أَهْلِهِ مِنْ أَوَّلِ يَوْمِهِ وَطَلَعَ لَهُ الْفَجْرُ قَبْلَ أَنْ يَدْخُلَ دَخَلَ وَهُوَ صَائِمٌ ‏.‏ قَالَ مَالِكٌ وَإِذَا أَرَادَ أَنْ يَخْرُجَ فِي رَمَضَانَ فَطَلَعَ لَهُ الْفَجْرُ وَهُوَ بِأَرْضِهِ قَبْلَ أَنْ يَخْرُجَ فَإِنَّهُ يَصُومُ ذَلِكَ الْيَوْمَ ‏.‏ قَالَ مَالِكٌ فِي الرَّجُلِ يَقْدَمُ مِنْ سَفَرِهِ وَهُوَ مُفْطِرٌ وَامْرَأَتُهُ مُفْطِرَةٌ حِينَ طَهُرَتْ مِنْ حَيْضِهَا فِي رَمَضَانَ أَنَّ لِزَوْجِهَا أَنْ يُصِيبَهَا إِنْ شَاءَ ‏.‏\hadithno{658}\hadithgrade{Salim al-Hilali: Mauquf Daif}\hadithtrans{Yahya related to me from Malik that he had heard that Umar ibn al-Khattab, if he was travelling in Ramadan and knew that he would reach Madina at the begining of the day ,would do so fasting. Yahya said that Malik said, "Someone who is travelling and knows that he will be reaching his people in the first part of the day, and then dawn breaks before he gets there, should be fasting when he gets there." Malik said, "Someone who intends to go away (on a journey) in Ramadan, and then dawn breaks while he is still on his land before he has left, should fast that day." Malik said that a man who returns from a journey in Ramadan and is not fasting may have sexual intercourse with his wife if he wishes, if she is not fasting and she has just become pure after her menses}}
\hadithdefcmd{malik}{659}{حَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، عَنِ ابْنِ شِهَابٍ، عَنْ حُمَيْدِ بْنِ عَبْدِ الرَّحْمَنِ بْنِ عَوْفٍ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَجُلاً، أَفْطَرَ فِي رَمَضَانَ فَأَمَرَهُ رَسُولُ اللَّهِ صلى الله عليه وسلم أَنْ يُكَفِّرَ بِعِتْقِ رَقَبَةٍ أَوْ صِيَامِ شَهْرَيْنِ مُتَتَابِعَيْنِ أَوْ إِطْعَامِ سِتِّينَ مِسْكِينًا ‏.‏ فَقَالَ لاَ أَجِدُ ‏.‏ فَأُتِيَ رَسُولُ اللَّهِ صلى الله عليه وسلم بِعَرَقِ تَمْرٍ ‏.‏ فَقَالَ ‏"‏ خُذْ هَذَا فَتَصَدَّقْ بِهِ ‏"‏ ‏.‏ فَقَالَ يَا رَسُولَ اللَّهِ مَا أَحَدٌ أَحْوَجَ مِنِّي ‏.‏ فَضَحِكَ رَسُولُ اللَّهِ صلى الله عليه وسلم حَتَّى بَدَتْ أَنْيَابُهُ ثُمَّ قَالَ ‏"‏ كُلْهُ ‏"‏ ‏.‏\hadithno{659}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Ibn Shihab from Hunayd ibn Abd arRahman ibn Awf from Abu Hurayra that a man broke the fast in Ramadan and the Messenger of Allah, may Allah bless him and grant him peace, ordered him to make kaffara by freeing a slave, or fasting two consecutive months, or feeding sixty poor people, and he said, "I can't do it." Someone brought a large basket of dates to the Messenger of Allah, may Allah bless him and grant him peace, and he said, "Take this and give it away as sadaqa." He said, "Messenger of Allah, there is no-ne more needy than I am." The Messenger of Allah, may Allah bless him and grant him peace, laughed until his eye-teeth appeared, and then he said, "Eat them}}
\hadithdefcmd{malik}{660}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ عَطَاءِ بْنِ عَبْدِ اللَّهِ الْخُرَاسَانِيِّ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، أَنَّهُ قَالَ جَاءَ أَعْرَابِيٌّ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم يَضْرِبُ نَحْرَهُ وَيَنْتِفُ شَعْرَهُ وَيَقُولُ هَلَكَ الأَبْعَدُ ‏.‏ فَقَالَ لَهُ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ وَمَا ذَاكَ ‏"‏ ‏.‏ فَقَالَ أَصَبْتُ أَهْلِي وَأَنَا صَائِمٌ فِي رَمَضَانَ ‏.‏ فَقَالَ لَهُ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ هَلْ تَسْتَطِيعُ أَنْ تُعْتِقَ رَقَبَةً ‏"‏ ‏.‏ فَقَالَ لاَ ‏.‏ فَقَالَ ‏"‏ هَلْ تَسْتَطِيعُ أَنْ تُهْدِيَ بَدَنَةً ‏"‏ ‏.‏ قَالَ لاَ ‏.‏ قَالَ ‏"‏ فَاجْلِسْ ‏"‏ ‏.‏ فَأُتِيَ رَسُولُ اللَّهِ صلى الله عليه وسلم بِعَرَقِ تَمْرٍ فَقَالَ ‏"‏ خُذْ هَذَا فَتَصَدَّقْ بِهِ ‏"‏ ‏.‏ فَقَالَ مَا أَحَدٌ أَحْوَجَ مِنِّي ‏.‏ فَقَالَ ‏"‏ كُلْهُ وَصُمْ يَوْمًا مَكَانَ مَا أَصَبْتَ ‏"‏ ‏.‏ قَالَ مَالِكٌ قَالَ عَطَاءٌ فَسَأَلْتُ سَعِيدَ بْنَ الْمُسَيَّبِ كَمْ فِي ذَلِكَ الْعَرَقِ مِنَ التَّمْرِ فَقَالَ مَا بَيْنَ خَمْسَةَ عَشَرَ صَاعًا إِلَى عِشْرِينَ ‏.‏\hadithno{660}\hadithgrade{Salim al-Hilali: Daif}\hadithtrans{Yahya related to me from Malik from Ata ibn Abdullah al-Khurasani that Said ibn al-Musayyab said, "A bedouin came to the Messenger of Allah, may Allah bless him and grant him peace, beating his breast and tearing out his hair and saying, 'I am destroyed.' The Messenger of Allah, may Allah bless him and grant him peace, said, 'Why is that?', and he said, 'I had intercourse with my wife while fasting in Ramadan.' The Messenger of Allah, may Allah bless him and grant him peace, asked him, 'Are you able to free a slave?', and the man said, 'No.' Then he asked him, 'Are you able to give away a camel?', and the man replied, 'No.' He said, 'Sit own,' and someone brought a large basket of dates to the Messenger of Allah, may Allah bless him and grant him peace, and he said to the man, 'Take this and give it away as sadaqa.' The man said, 'There is no one more needy than me,' and (the Messenger of Allah, may Allah bless him and grant him peace), said, 'Eat them, and fast one day for the day when you had intercourse.' " Malik said that Ata said that he had asked Said ibn al-Musayyab how many dates there were in that basket, and he said, "Between fifteen and twenty sas}}
\hadithdefcmd{malik}{661}{حَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، عَنْ نَافِعٍ، عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ، أَنَّهُ كَانَ يَحْتَجِمُ وَهُوَ صَائِمٌ - قَالَ - ثُمَّ تَرَكَ ذَلِكَ بَعْدُ فَكَانَ إِذَا صَامَ لَمْ يَحْتَجِمْ حَتَّى يُفْطِرَ ‏.‏\hadithno{661}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Malik said, "I have heard people of knowledge saying that the kaffara specified by the Messenger of Allah, may Allah bless him and grant him peace, for a man who has intercourse with his wife during the day in Ramadan is not due from someone who, on a day when he is making up the fast of Ramadan, breaks his fast by having intercourse with his wife, or whatever. He only has to make up for that day." Malik said, "This is what I like most out of what I have heard about the matter." Yahya related to me from Malik from Nafi that Abdullah ibn Umar used to be cupped while he was fasting. Nafi said, "He later stopped doing that, and would not be cupped when he was fasting until he had broken the fast}}
\hadithdefcmd{malik}{662}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنِ ابْنِ شِهَابٍ، أَنَّ سَعْدَ بْنَ أَبِي وَقَّاصٍ، وَعَبْدَ اللَّهِ بْنَ عُمَرَ، كَانَا يَحْتَجِمَانِ وَهُمَا صَائِمَانِ ‏.‏\hadithno{662}\hadithgrade{Salim al-Hilali: Mauquf Daif}\hadithtrans{Yahya related to me from Malik from Ibn Shihab that Sad ibn Abi Waqqas and Abdullah ibn Umar used to be cupped while they were fasting}}
\hadithdefcmd{malik}{663}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، أَنَّهُ كَانَ يَحْتَجِمُ وَهُوَ صَائِمٌ ثُمَّ لاَ يُفْطِرُ ‏.‏ قَالَ وَمَا رَأَيْتُهُ احْتَجَمَ قَطُّ إِلاَّ وَهُوَ صَائِمٌ ‏.‏ قَالَ مَالِكٌ لاَ تُكْرَهُ الْحِجَامَةُ لِلصَّائِمِ إِلاَّ خَشْيَةً مِنْ أَنْ يَضْعُفَ وَلَوْلاَ ذَلِكَ لَمْ تُكْرَهْ وَلَوْ أَنَّ رَجُلاً احْتَجَمَ فِي رَمَضَانَ ثُمَّ سَلِمَ مِنْ أَنْ يُفْطِرَ لَمْ أَرَ عَلَيْهِ شَيْئًا وَلَمْ آمُرْهُ بِالْقَضَاءِ لِذَلِكَ الْيَوْمِ الَّذِي احْتَجَمَ فِيهِ لأَنَّ الْحِجَامَةَ إِنَّمَا تُكْرَهُ لِلصَّائِمِ لِمَوْضِعِ التَّغْرِيرِ بِالصِّيَامِ فَمَنِ احْتَجَمَ وَسَلِمَ مِنْ أَنْ يُفْطِرَ حَتَّى يُمْسِيَ فَلاَ أَرَى عَلَيْهِ شَيْئًا وَلَيْسَ عَلَيْهِ قَضَاءُ ذَلِكَ الْيَوْمِ ‏.‏\hadithno{663}\hadithgrade{Salim al-Hilali: Maqtu Sahih}\hadithtrans{Yahya related to me from Malik from Hisham ibn Urwa that his father used to be cupped while he was fasting and he would not then break his fast. Hisham added, "I only ever saw him being cupped when he was fasting." Malik said, "Cupping is only disapproved of for some one who is fasting out of fear that he will become weak and if it were not for that, it would not be disapproved of. I do not think that a man who is cupped in Ramadan and does not break his fast, owes anything, and I do not say that he has to make up for the day on which he was cupped, because cupping is only disapproved of for someone fasting if his fast is endangered. I do not think that someone who is cupped, and is then well enough to keep the fast until evening, owes anything, nor does he have to make up for that day}}
\hadithdefcmd{malik}{664}{حَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، زَوْجِ النَّبِيِّ صلى الله عليه وسلم أَنَّهَا قَالَتْ كَانَ يَوْمُ عَاشُورَاءَ يَوْمًا تَصُومُهُ قُرَيْشٌ فِي الْجَاهِلِيَّةِ وَكَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَصُومُهُ فِي الْجَاهِلِيَّةِ فَلَمَّا قَدِمَ رَسُولُ اللَّهِ صلى الله عليه وسلم الْمَدِينَةَ صَامَهُ وَأَمَرَ بِصِيَامِهِ فَلَمَّا فُرِضَ رَمَضَانُ كَانَ هُوَ الْفَرِيضَةَ وَتُرِكَ يَوْمُ عَاشُورَاءَ فَمَنْ شَاءَ صَامَهُ وَمَنْ شَاءَ تَرَكَهُ ‏.‏\hadithno{664}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Hisham ibn Urwa from his father that A'isha, the wife of the Prophet, may Allah bless him and grant him peace, said, "The day of Ashura was a day the Quraysh used to fast in the jahiliyya, and the Messenger of Allah, may Allah bless him and grant him peace, used also to fast it during the jahiliyya. Then when the Messenger of Allah, may Allah bless him and grant him peace, came to Madina he fasted it and ordered that it be fasted. Then Ramadan was made obligatory, and that became the fard instead of Ashura, but whoever wanted to, fasted it, and whoever did not want to, did not fast it}}
\hadithdefcmd{malik}{665}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنِ ابْنِ شِهَابٍ، عَنْ حُمَيْدِ بْنِ عَبْدِ الرَّحْمَنِ بْنِ عَوْفٍ، أَنَّهُ سَمِعَ مُعَاوِيَةَ بْنَ أَبِي سُفْيَانَ، يَوْمَ عَاشُورَاءَ عَامَ حَجَّ وَهُوَ عَلَى الْمِنْبَرِ يَقُولُ يَا أَهْلَ الْمَدِينَةِ أَيْنَ عُلَمَاؤُكُمْ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ لِهَذَا الْيَوْمِ ‏ "‏ هَذَا يَوْمُ عَاشُورَاءَ وَلَمْ يُكْتَبْ عَلَيْكُمْ صِيَامُهُ وَأَنَا صَائِمٌ فَمَنْ شَاءَ فَلْيَصُمْ وَمَنْ شَاءَ فَلْيُفْطِرْ ‏"‏ ‏.‏\hadithno{665}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Ibn Shihab that Humayd ibn Abd ar-Rahman ibn Awf heard Muawiya ibn Abi Sufyan say from the mimbar on the day of Ashura in the year in which he made the hajj, "People of Madina, where are your learned men? I heard the Messenger of Allah, may Allah bless him and grant him peace, say about this day, 'This is the day of Ashura, and fasting it has not been prescribed for you. I am fasting it, and whoever of you wants to fast it can do so, and whoever does not want to, does not have to}}
\hadithdefcmd{malik}{666}{وَحَدَّثَنِي عَنْ مَالِكٍ، أَنَّهُ بَلَغَهُ أَنَّ عُمَرَ بْنَ الْخَطَّابِ، أَرْسَلَ إِلَى الْحَارِثِ بْنِ هِشَامٍ أَنَّ غَدًا، يَوْمُ عَاشُورَاءَ فَصُمْ وَأْمُرْ أَهْلَكَ أَنْ يَصُومُوا ‏.‏\hadithno{666}\hadithgrade{Salim al-Hilali: Mauquf Daif}\hadithtrans{Yahya related to me from Malik that he had heard that Umar ibn al-Khattab had sent (the following message) to al-Harith ibn Hisham, ''Tomorrow is the day of Ashura, so fast (it) and tell your family to fast (also)}}
\hadithdefcmd{malik}{667}{حَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، عَنْ مُحَمَّدِ بْنِ يَحْيَى بْنِ حَبَّانَ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ، ‏.‏ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم نَهَى عَنْ صِيَامِ يَوْمَيْنِ يَوْمِ الْفِطْرِ وَيَوْمِ الأَضْحَى ‏.‏\hadithno{667}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Muhammad ibn Yahya ibn Habban from alAraj from Abu Hurayra that the Messenger of Allah, may Allah bless him and grant him peace, forbade fasting on two days, the day of Fitr and the day of Adha}}
\hadithdefcmd{malik}{668}{وَحَدَّثَنِي عَنْ مَالِكٍ، أَنَّهُ سَمِعَ أَهْلَ الْعِلْمِ، يَقُولُونَ لاَ بَأْسَ بِصِيَامِ الدَّهْرِ إِذَا أَفْطَرَ الأَيَّامَ الَّتِي نَهَى رَسُولُ اللَّهِ صلى الله عليه وسلم عَنْ صِيَامِهَا وَهِيَ أَيَّامُ مِنًى وَيَوْمُ الأَضْحَى وَيَوْمُ الْفِطْرِ فِيمَا بَلَغَنَا ‏.‏ قَالَ وَذَلِكَ أَحَبُّ مَا سَمِعْتُ إِلَىَّ فِي ذَلِكَ ‏.‏\hadithno{668}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik that he used to hear the people of knowledge say,"There is no harm in fasting continuously as long as one breaks the fast on the days on which the Messenger of Allah, may Allah bless him and grant him peace, forbade fasting, namely, the days of Mina, the day of Adha and the day of Fitr, according to what we have heard." Malik said, "This is what I like most out of what I have heard about the matter}}
\hadithdefcmd{malik}{669}{حَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، عَنْ نَافِعٍ، عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم نَهَى عَنِ الْوِصَالِ فَقَالُوا يَا رَسُولَ اللَّهِ فَإِنَّكَ تُوَاصِلُ فَقَالَ ‏ "‏ إِنِّي لَسْتُ كَهَيْئَتِكُمْ إِنِّي أُطْعَمُ وَأُسْقَى ‏"‏ ‏.‏\hadithno{669}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Nafi from Abdullah ibn Umar that the Messenger of Allah, may Allah bless him and grant him peace, forbade fasting for two days or more without breaking the fast in between. They said, "But Messenger of Allah, you practise wisal." He replied, "I am not the same as you. I am fed and given to drink}}
\hadithdefcmd{malik}{670}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ أَبِي الزِّنَادِ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏"‏ إِيَّاكُمْ وَالْوِصَالَ إِيَّاكُمْ وَالْوِصَالَ ‏"‏ ‏.‏ قَالُوا فَإِنَّكَ تُوَاصِلُ يَا رَسُولَ اللَّهِ ‏.‏ قَالَ ‏"‏ إِنِّي لَسْتُ كَهَيْئَتِكُمْ إِنِّي أَبِيتُ يُطْعِمُنِي رَبِّي وَيَسْقِينِي ‏"‏ ‏.‏\hadithno{670}\hadithgrade{Salim al-Hilali: Daif}\hadithtrans{Yahya related to me from Malik from Abu'z-Zinad from al-Araj from Abu Hurayra that the Messenger of Allah, may Allah bless him and grant him peace, said, "Beware of wisal. Beware of wisal." They said, "But you practise wisal, Messenger of Allah." He replied, "I am not the same as you. My Lord feeds me and gives me to drink}}
\hadithdefcmd{malik}{671}{\hadithno{671}\hadithgrade{Salim al-Hilali: Maqtu Daif}\hadithtrans{}}
\hadithdefcmd{malik}{672}{قَالَ مَالِكٌ وَبَلَغَنِي عَنْ سُلَيْمَانَ بْنِ يَسَارٍ، مِثْلُ ذَلِكَ ‏.‏ قَالَ مَالِكٌ مَنْ مَاتَ وَعَلَيْهِ نَذْرٌ مِنْ رَقَبَةٍ يُعْتِقُهَا أَوْ صِيَامٍ أَوْ صَدَقَةٍ أَوْ بَدَنَةٍ فَأَوْصَى بِأَنْ يُوَفَّى ذَلِكَ عَنْهُ مِنْ مَالِهِ فَإِنَّ الصَّدَقَةَ وَالْبَدَنَةَ فِي ثُلُثِهِ وَهُوَ يُبَدَّى عَلَى مَا سِوَاهُ مِنَ الْوَصَايَا إِلاَّ مَا كَانَ مِثْلَهُ وَذَلِكَ أَنَّهُ لَيْسَ الْوَاجِبُ عَلَيْهِ مِنَ النُّذُورِ وَغَيْرِهَا كَهَيْئَةِ مَا يَتَطَوَّعُ بِهِ مِمَّا لَيْسَ بِوَاجِبٍ وَإِنَّمَا يُجْعَلُ ذَلِكَ فِي ثُلُثِهِ خَاصَّةً دُونَ رَأْسِ مَالِهِ لأَنَّهُ لَوْ جَازَ لَهُ ذَلِكَ فِي رَأْسِ مَالِهِ لأَخَّرَ الْمُتَوَفَّى مِثْلَ ذَلِكَ مِنَ الأُمُورِ الْوَاجِبَةِ عَلَيْهِ حَتَّى إِذَا حَضَرَتْهُ الْوَفَاةُ وَصَارَ الْمَالُ لِوَرَثَتِهِ سَمَّى مِثْلَ هَذِهِ الأَشْيَاءِ الَّتِي لَمْ يَكُنْ يَتَقَاضَاهَا مِنْهُ مُتَقَاضٍ فَلَوْ كَانَ ذَلِكَ جَائِزًا لَهُ أَخَّرَ هَذِهِ الأَشْيَاءَ حَتَّى إِذَا كَانَ عِنْدَ مَوْتِهِ سَمَّاهَا وَعَسَى أَنْ يُحِيطَ بِجَمِيعِ مَالِهِ فَلَيْسَ ذَلِكَ لَهُ ‏.‏\hadithno{672}\hadithgrade{Salim al-Hilali: Maqtu Daif}\hadithtrans{}}
\hadithdefcmd{malik}{673}{وَحَدَّثَنِي عَنْ مَالِكٍ، أَنَّهُ بَلَغَهُ أَنَّ عَبْدَ اللَّهِ بْنَ عُمَرَ، كَانَ يُسْأَلُ هَلْ يَصُومُ أَحَدٌ عَنْ أَحَدٍ، أَوْ يُصَلِّي أَحَدٌ عَنْ أَحَدٍ، فَيَقُولُ لاَ يَصُومُ أَحَدٌ عَنْ أَحَدٍ، وَلاَ يُصَلِّي أَحَدٌ عَنْ أَحَدٍ‏.‏\hadithno{673}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Hadith Translation Not available}}
\hadithdefcmd{malik}{674}{حَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، عَنْ زَيْدِ بْنِ أَسْلَمَ، عَنْ أَخِيهِ، خَالِدِ بْنِ أَسْلَمَ أَنَّ عُمَرَ بْنَ الْخَطَّابِ، أَفْطَرَ ذَاتَ يَوْمٍ فِي رَمَضَانَ فِي يَوْمٍ ذِي غَيْمٍ وَرَأَى أَنَّهُ قَدْ أَمْسَى وَغَابَتِ الشَّمْسُ ‏.‏ فَجَاءَهُ رَجُلٌ فَقَالَ يَا أَمِيرَ الْمُؤْمِنِينَ طَلَعَتِ الشَّمْسُ ‏.‏ فَقَالَ عُمَرُ الْخَطْبُ يَسِيرٌ وَقَدِ اجْتَهَدْنَا ‏.‏ قَالَ مَالِكٌ يُرِيدُ بِقَوْلِهِ الْخَطْبُ يَسِيرٌ الْقَضَاءَ فِيمَا نُرَى - وَاللَّهُ أَعْلَمُ - وَخِفَّةَ مَؤُونَتِهِ وَيَسَارَتِهِ يَقُولُ نَصُومُ يَوْمًا مَكَانَهُ ‏.‏\hadithno{674}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Yahya related to me from Malik from Zayd ibn Aslam from his brother Khalid ibn Aslam that Umar ibn al-Khattab once broke thefast on a cloudy day thinking that evening had come and the sun had set. Then a man came to him and said, "Amir al-muminin, the sun has come out,'' and Umar said, "That's an easy matter. It was our deduction (ijtihad)." Malik said, "According to what we think, and Allah knows best, what he was referring to when he said, 'That's an easy matter' was making up the fast, and how slight the effort involved was and how easy it was. He was saying (in effect), 'We will fast another day in its place}}
\hadithdefcmd{malik}{675}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ نَافِعٍ، أَنَّ عَبْدَ اللَّهِ بْنَ عُمَرَ، كَانَ يَقُولُ يَصُومُ قَضَاءَ رَمَضَانَ مُتَتَابِعًا مَنْ أَفْطَرَهُ مِنْ مَرَضٍ أَوْ فِي سَفَرٍ ‏.‏\hadithno{675}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Yahya related to me from Malik from Nafi that Abdullah ibn Umar used to say, "Someone who breaks the fast in Ramadan because he is ill or travelling should make up the days he has missed consecutively}}
\hadithdefcmd{malik}{676}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنِ ابْنِ شِهَابٍ، أَنَّ عَبْدَ اللَّهِ بْنَ عَبَّاسٍ، وَأَبَا، هُرَيْرَةَ اخْتَلَفَا فِي قَضَاءِ رَمَضَانَ فَقَالَ أَحَدُهُمَا يُفَرِّقُ بَيْنَهُ ‏.‏ وَقَالَ الآخَرُ لاَ يُفَرِّقُ بَيْنَهُ ‏.‏ لاَ أَدْرِي أَيَّهُمَا قَالَ يُفَرِّقُ بَيْنَهُ ‏.‏\hadithno{676}\hadithgrade{Salim al-Hilali: Mauquf Daif}\hadithtrans{Yahya related to me from Malik from Ibr Shihab that Abdullah ibn Abbas and Abu Hurayra differed about making up days missed in Ramadan. One of them said that they were done separately and the other said that they were done consecutively. He did not know which one of them it was who said that they were done separately}}
\hadithdefcmd{malik}{677}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ نَافِعٍ، عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ، أَنَّهُ كَانَ يَقُولُ مَنِ اسْتَقَاءَ وَهُوَ صَائِمٌ فَعَلَيْهِ الْقَضَاءُ وَمَنْ ذَرَعَهُ الْقَىْءُ فَلَيْسَ عَلَيْهِ الْقَضَاءُ ‏.‏\hadithno{677}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Yahya related to me from Malik from Nafi that Abdullah ibn Umar used to say, "If some one makes himself vomit while he is fasting he has to make up a day, but if he cannot help vomiting he does not have to make up anything}}
\hadithdefcmd{malik}{678}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ يَحْيَى بْنِ سَعِيدٍ، أَنَّهُ سَمِعَ سَعِيدَ بْنَ الْمُسَيَّبِ، يُسْأَلُ عَنْ قَضَاءِ، رَمَضَانَ فَقَالَ سَعِيدٌ أَحَبُّ إِلَىَّ أَنْ لاَ يُفَرَّقَ قَضَاءُ رَمَضَانَ وَأَنْ يُوَاتَرَ ‏.‏ قَالَ يَحْيَى سَمِعْتُ مَالِكًا يَقُولُ فِيمَنْ فَرَّقَ قَضَاءَ رَمَضَانَ فَلَيْسَ عَلَيْهِ إِعَادَةٌ وَذَلِكَ مُجْزِئٌ عَنْهُ وَأَحَبُّ ذَلِكَ إِلَىَّ أَنْ يُتَابِعَهُ ‏.‏ قَالَ مَالِكٌ مَنْ أَكَلَ أَوْ شَرِبَ فِي رَمَضَانَ سَاهِيًا أَوْ نَاسِيًا أَوْ مَا كَانَ مِنْ صِيَامٍ وَاجِبٍ عَلَيْهِ أَنَّ عَلَيْهِ قَضَاءَ يَوْمٍ مَكَانَهُ ‏.‏\hadithno{678}\hadithgrade{Salim al-Hilali: Maqtu Sahih}\hadithtrans{Yahya related to me from Malik from Yahya ibn Said that he heard Said ibn al Musayyab being asked about making up days missed in Ramadan, and Said said, "What I like best is for days missed in Ramadan to be made up consecutively, and not separately." Yahya said that he had heard Malik say, about some one who made up the days he had missed in Ramadan separately, that he did not have to repeat them. (What he had done) was enough for him. It was, however, preferable, if he did them consecutively. Malik said, "Whoever eats or drinks thoughtlessly or forgetfully in Ramadan or during any other obligatory fast that he must do, has to fast another day in its place}}
\hadithdefcmd{malik}{679}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ حُمَيْدِ بْنِ قَيْسٍ الْمَكِّيِّ، أَنَّهُ أَخْبَرَهُ قَالَ كُنْتُ مَعَ مُجَاهِدٍ وَهُوَ يَطُوفُ بِالْبَيْتِ فَجَاءَهُ إِنْسَانٌ فَسَأَلَهُ عَنْ صِيَامِ أَيَّامِ الْكَفَّارَةِ أَمُتَتَابِعَاتٍ أَمْ يَقْطَعُهَا قَالَ حُمَيْدٌ فَقُلْتُ لَهُ نَعَمْ يَقْطَعُهَا إِنْ شَاءَ ‏.‏ قَالَ مُجَاهِدٌ لاَ يَقْطَعُهَا فَإِنَّهَا فِي قِرَاءَةِ أُبَىِّ بْنِ كَعْبٍ ثَلاَثَةِ أَيَّامٍ مُتَتَابِعَاتٍ ‏.‏ قَالَ مَالِكٌ وَأَحَبُّ إِلَىَّ أَنْ يَكُونَ مَا سَمَّى اللَّهُ فِي الْقُرْآنِ يُصَامُ مُتَتَابِعًا ‏.‏ وَسُئِلَ مَالِكٌ عَنِ الْمَرْأَةِ تُصْبِحُ صَائِمَةً فِي رَمَضَانَ فَتَدْفَعُ دَفْعَةً مِنْ دَمٍ عَبِيطٍ فِي غَيْرِ أَوَانِ حَيْضِهَا ثُمَّ تَنْتَظِرُ حَتَّى تُمْسِيَ أَنْ تَرَى مِثْلَ ذَلِكَ فَلاَ تَرَى شَيْئًا ثُمَّ تُصْبِحُ يَوْمًا آخَرَ فَتَدْفَعُ دَفْعَةً أُخْرَى وَهِيَ دُونَ الأُولَى ثُمَّ يَنْقَطِعُ ذَلِكَ عَنْهَا قَبْلَ حَيْضَتِهَا بِأَيَّامٍ فَسُئِلَ مَالِكٌ كَيْفَ تَصْنَعُ فِي صِيَامِهَا وَصَلاَتِهَا قَالَ مَالِكٌ ذَلِكَ الدَّمُ مِنَ الْحَيْضَةِ فَإِذَا رَأَتْهُ فَلْتُفْطِرْ وَلْتَقْضِ مَا أَفْطَرَتْ فَإِذَا ذَهَبَ عَنْهَا الدَّمُ فَلْتَغْتَسِلْ وَتَصُومُ ‏.‏ وَسُئِلَ عَمَّنْ أَسْلَمَ فِي آخِرِ يَوْمٍ مِنْ رَمَضَانَ هَلْ عَلَيْهِ قَضَاءُ رَمَضَانَ كُلِّهِ أَوْ يَجِبُ عَلَيْهِ قَضَاءُ الْيَوْمِ الَّذِي أَسْلَمَ فِيهِ فَقَالَ لَيْسَ عَلَيْهِ قَضَاءُ مَا مَضَى وَإِنَّمَا يَسْتَأْنِفُ الصِّيَامَ فِيمَا يُسْتَقْبَلُ وَأَحَبُّ إِلَىَّ أَنْ يَقْضِيَ الْيَوْمَ الَّذِي أَسْلَمَ فِيهِ ‏.‏\hadithno{679}\hadithgrade{Salim al-Hilali: Hasan}\hadithtrans{Yahya related to me from Malik that Humayd ibn Oays al-Makki told him, "I was with Mujahid while he was performing tawaf around the Kaba, and a man came to him and asked whether the days (of fasting) for kaffara had to be fasted consecutively, or could they be split up. I said to him, 'Yes, they can be split up, if the person so wishes.' Mujahid said, 'He should not split them up, because in Ubayy ibn Kab's recitation they are referred to as three consecutive days.' " Malik said, "What I like most is what Allah has specified in the Qur'an, that is, that they are fasted consecutively." Malik was asked about a woman who began the day fasting in Ramadan and though it was outside of the time of her period, fresh blood (i.e. not menstrual blood) flowed from her. She then waited until evening to see the same, but did not see anything.Then, on the next day in the morning she had anotherflow, though less than the first. Then, some days before her period, the flow stopped completely. Malik was asked what she should do about her fasting and prayer, and he said, "This blood is like menstrual blood. When she sees it she should break her fast, and then make up the days she has missed. Then, when the blood has completely stopped, she should do ghusl and fast." Malik was asked whether someone who became muslim on the last day of Ramadan had to make up all of Ramadan or whether he just had to make up the day when he became muslim, and he said, "He does not have to make up any of the days that have passed. He begins fasting from that day onwards. What I like most is that he makes up the day on which he became muslim}}
\hadithdefcmd{malik}{680}{حَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، عَنِ ابْنِ شِهَابٍ، أَنَّ عَائِشَةَ، وَحَفْصَةَ، زَوْجَىِ النَّبِيِّ صلى الله عليه وسلم أَصْبَحَتَا صَائِمَتَيْنِ مُتَطَوِّعَتَيْنِ فَأُهْدِيَ لَهُمَا طَعَامٌ فَأَفْطَرَتَا عَلَيْهِ فَدَخَلَ عَلَيْهِمَا رَسُولُ اللَّهِ صلى الله عليه وسلم قَالَتْ عَائِشَةُ فَقَالَتْ حَفْصَةُ وَبَدَرَتْنِي بِالْكَلاَمِ - وَكَانَتْ بِنْتَ أَبِيهَا - يَا رَسُولَ اللَّهِ إِنِّي أَصْبَحْتُ أَنَا وَعَائِشَةُ صَائِمَتَيْنِ مُتَطَوِّعَتَيْنِ فَأُهْدِيَ إِلَيْنَا طَعَامٌ فَأَفْطَرْنَا عَلَيْهِ ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ اقْضِيَا مَكَانَهُ يَوْمًا آخَرَ ‏"‏ ‏.‏\hadithno{680}\hadithgrade{Salim al-Hilali: Munkar}\hadithtrans{Yahya related to me from Malik from Ibn Shihab that A'isha and Hafsa, the wives of the Prophet, may Allah bless him and grant him peace, began fasting voluntarily one morning and then food was given to them and they broke their fast with it. Then the Messenger of Allah, may Allah bless him and grant him peace, came in. A'isha said, "Hafsa asked, anticipating me in speech - she took after her father Umar - 'Messenger of Allah, A'isha and I began the morning fasting voluntarily and then food was given us and we broke the fast with it.' The Messenger of Allah, may Allah bless him and grant him peace, said, 'Fast another day in its place}}
\hadithdefcmd{malik}{681}{حَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، أَنَّهُ بَلَغَهُ أَنَّ أَنَسَ بْنَ مَالِكٍ، كَبِرَ حَتَّى كَانَ لاَ يَقْدِرُ عَلَى الصِّيَامِ فَكَانَ يَفْتَدِي ‏.‏ قَالَ مَالِكٌ وَلاَ أَرَى ذَلِكَ وَاجِبًا وَأَحَبُّ إِلَىَّ أَنْ يَفْعَلَهُ إِذَا كَانَ قَوِيًّا عَلَيْهِ فَمَنْ فَدَى فَإِنَّمَا يُطْعِمُ مَكَانَ كُلِّ يَوْمٍ مُدًّا بِمُدِّ النَّبِيِّ صلى الله عليه وسلم ‏.‏\hadithno{681}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Yahya said that he heard Malik say, "Someone who eats or drinks out of neglect or forgetfulness during a voluntary fast does not have to repeat his fast, but he should continue fasting for the rest of the day in which he eats or drinks while voluntarily fasting, and not stop fasting. Someone to whom something unexpected happens which causes him to break his fast while he is fasting voluntarily does not have to repeat his fast if he has broken it for a reason, and not simply because he decided to break his fast. Just as I do not think that someone has to repeat a voluntary prayer if he has had to stop it because of some discharge which he could prevent and which meant that he had to repeat his wudu." Malik said, "Once a man has begun doing any of the right actions (al-amal as-saliha) such as the prayer, the fast and the hajj, or similar right actions of a voluntary nature, he should not stop until he has completed it according to what the sunna for that action is. If he says the takbir he should not stop until he has prayed two rakas. If he is fasting he should not break his fast until he has completed that day's fast. If he goes into ihram he should not return until he has completed his hajj, and if he begins doing tawaf he should not stop doing so until he has gone around the Kaba seven times. He should not stop doing any of these actions once he has started them until he has completed them, except if something happens such as illness or some other matter by which a man is excused. This is because Allah, the Blessed and Exalted, says in His Book, 'And eat and drink until the white thread becomes clear to you from the black thread of dawn, (and) then complete the fast until night-time,' (Sura 2 ayat 187), and so he must complete his fast as Allah has said. Allah, the Exalted, (also) says, 'And complete the hajj and the umra for Allah,' and so if a man were to go into ihram for a voluntary hajj having done his one obligatory hajj (on a previous occasion), he could not then stop doing his hajj having once begun it and leave ihram while in the middle of his hajj. Anyone that begins a voluntary act must complete it once he has begun doing it, just as an obligatory act must be completed . This is the best of what I have heard." Yahya related to me from Malik that he had heard that Anas ibn Malik used to pay fidya when he had grown old and could no longer manage to do the fast. Malik said, "I do not consider that to do so is obligatory, but what I like most is that a man does the fast when he is strong enough. Whoever pays compensation gives one mudd of food in place of every day, using the mudd of the Prophet, may Allah bless him and grant him peace}}
\hadithdefcmd{malik}{682}{وَحَدَّثَنِي عَنْ مَالِكٍ، أَنَّهُ بَلَغَهُ أَنَّ عَبْدَ اللَّهِ بْنَ عُمَرَ، سُئِلَ عَنِ الْمَرْأَةِ الْحَامِلِ، إِذَا خَافَتْ عَلَى وَلَدِهَا وَاشْتَدَّ عَلَيْهَا الصِّيَامُ قَالَ تُفْطِرُ وَتُطْعِمُ مَكَانَ كُلِّ يَوْمٍ مِسْكِينًا مُدًّا مِنْ حِنْطَةٍ بِمُدِّ النَّبِيِّ صلى الله عليه وسلم ‏.‏ قَالَ مَالِكٌ وَأَهْلُ الْعِلْمِ يَرَوْنَ عَلَيْهَا الْقَضَاءَ كَمَا قَالَ اللَّهُ عَزَّ وَجَلَّ ‏\{‏فَمَنْ كَانَ مِنْكُمْ مَرِيضًا أَوْ عَلَى سَفَرٍ فَعِدَّةٌ مِنْ أَيَّامٍ أُخَرَ‏\}‏ وَيَرَوْنَ ذَلِكَ مَرَضًا مِنَ الأَمْرَاضِ مَعَ الْخَوْفِ عَلَى وَلَدِهَا ‏.‏\hadithno{682}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Yahya related to me from Malik that he had heard that Abdullah ibn Umar was asked about what a pregnant woman should do if the fast became difficult for her and she feared for her child, and he said, "She should break the fast and feed a poor man one mudd of wheat in place of every day, using the mudd of the Prophet, may Allah bless him and grant him peace." Malik said, "The people of knowledge consider that she has to make up for each day of the fast that she misses as Allah, the Exalted and Glorified, says, 'And whoever of you is sick or on a journey should fast an equal number of other days, ' and they consider her pregnancy and her concern for her child as a sickness}}
\hadithdefcmd{malik}{683}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ الْقَاسِمِ، عَنْ أَبِيهِ، أَنَّهُ كَانَ يَقُولُ مَنْ كَانَ عَلَيْهِ قَضَاءُ رَمَضَانَ فَلَمْ يَقْضِهِ - وَهُوَ قَوِيٌّ عَلَى صِيَامِهِ - حَتَّى جَاءَ رَمَضَانُ آخَرُ فَإِنَّهُ يُطْعِمُ مَكَانَ كُلِّ يَوْمٍ مِسْكِينًا مُدًّا مِنْ حِنْطَةٍ وَعَلَيْهِ مَعَ ذَلِكَ الْقَضَاءُ ‏.‏ وَحَدَّثَنِي عَنْ مَالِكٍ، أَنَّهُ بَلَغَهُ عَنْ سَعِيدِ بْنِ جُبَيْرٍ، مِثْلُ ذَلِكَ ‏.‏\hadithno{683}\hadithgrade{Salim al-Hilali: Maqtu Sahih}\hadithtrans{Yahya related to me from Malik from Abd ar-Rahman ibn al-Qasim that his father used to say, "If someone has to make up for days not fasted in Ramadan and does not do them before the next Ramadan comes although he is strong enough to do so, he should feed a poor man with a mudd of wheat for every day that he has missed, and he has to fast the days he owes as well." Yahya related to me from Malik that he had heard the same thing from Said ibn Jubayr}}
\hadithdefcmd{malik}{685}{حَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، عَنْ يَحْيَى بْنِ سَعِيدٍ، عَنْ أَبِي سَلَمَةَ بْنِ عَبْدِ الرَّحْمَنِ، أَنَّهُ سَمِعَ عَائِشَةَ، زَوْجَ النَّبِيِّ صلى الله عليه وسلم تَقُولُ إِنْ كَانَ لَيَكُونُ عَلَىَّ الصِّيَامُ مِنْ رَمَضَانَ فَمَا أَسْتَطِيعُ أَصُومُهُ حَتَّى يَأْتِيَ شَعْبَانُ\hadithno{685}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Yahya related to me from Malik from Yahya ibn Said from Abu Salama ibn Abd ar-Rahman that he heard A'isha, the wife of the Prophet, may Allah bless him and grant him peace, say, "I used to have to make up days from Ramadan and not be able to do them until Shaban came}}
\hadithdefcmd{malik}{686}{حَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، عَنْ أَبِي النَّضْرِ، مَوْلَى عُمَرَ بْنِ عُبَيْدِ اللَّهِ عَنْ أَبِي سَلَمَةَ بْنِ عَبْدِ الرَّحْمَنِ، عَنْ عَائِشَةَ، زَوْجِ النَّبِيِّ صلى الله عليه وسلم أَنَّهَا قَالَتْ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَصُومُ حَتَّى نَقُولَ لاَ يُفْطِرُ وَيُفْطِرُ حَتَّى نَقُولَ لاَ يَصُومُ وَمَا رَأَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم اسْتَكْمَلَ صِيَامَ شَهْرٍ قَطُّ إِلاَّ رَمَضَانَ وَمَا رَأَيْتُهُ فِي شَهْرٍ أَكْثَرَ صِيَامًا مِنْهُ فِي شَعْبَانَ ‏.‏\hadithno{686}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik that he had heard the people of knowledge telling people not to fast on the day in Shaban when there was doubt (about whether it was Shaban or Ramadan), if they intended by it the fast of Ramadan . They considered that whoever fasted on that day without having seen (the new moon) had to make up that day if it later became clear that it was part of Ramadan. They did not see any harm in voluntary fasting on that day. Malik said, "This is what we do, and what I have seen the people of knowledge in our city doing." Yahya related to me from Malik from Abu'n Nadr, the mawla of Umar ibn Ubaydullah, from Abu Salama ibn Abd ar-Rahman that A'isha, the wife of the Prophet, may Allah bless him and grant him peace, said, "The Messenger of Allah, may Allah bless him and grant him peace, used to fast for so long that we thought he would never stop fasting, and he would go without fasting for so long that we thought he would never fast again. I never saw the Messenger of Allah, may Allah bless him and grant him peace, fast for a complete month except for Ramadan, and I never saw him do more fasting in any one month than he did in Shaban}}
\hadithdefcmd{malik}{687}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ أَبِي الزِّنَادِ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ الصِّيَامُ جُنَّةٌ فَإِذَا كَانَ أَحَدُكُمْ صَائِمًا فَلاَ يَرْفُثْ وَلاَ يَجْهَلْ فَإِنِ امْرُؤٌ قَاتَلَهُ أَوْ شَاتَمَهُ فَلْيَقُلْ إِنِّي صَائِمٌ إِنِّي صَائِمٌ ‏"‏ ‏.‏\hadithno{687}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Abu'z Zinad from al-A'raj from Abu Hurayra that the Messenger of Allah, may Allah bless him and grant him peace, said, "Fasting is a protection for you, so when you are fasting, do not behave obscenely or foolishly, and if any one argues with you or abuses you, say, 'I am fasting. I am fasting}}
\hadithdefcmd{malik}{688}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ أَبِي الزِّنَادِ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ وَالَّذِي نَفْسِي بِيَدِهِ لَخُلُوفُ فَمِ الصَّائِمِ أَطْيَبُ عِنْدَ اللَّهِ مِنْ رِيحِ الْمِسْكِ إِنَّمَا يَذَرُ شَهْوَتَهُ وَطَعَامَهُ وَشَرَابَهُ مِنْ أَجْلِي فَالصِّيَامُ لِي وَأَنَا أَجْزِي بِهِ كُلُّ حَسَنَةٍ بِعَشْرِ أَمْثَالِهَا إِلَى سَبْعِمِائَةِ ضِعْفٍ إِلاَّ الصِّيَامَ فَهُوَ لِي وَأَنَا أَجْزِي بِهِ ‏"‏ ‏.‏\hadithno{688}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Abu'z Zinad from al-Araj from Abu Hurayra that the Messenger of Allah, may Allah bless him and grant him peace, said, "By the One in Whose hand my self is, the smell of the breath of a man fasting is better with Allah than the scent of musk.' He leaves his desires and his food and drink for My sake. Fasting is for Me and I reward it. Every good action is rewarded by ten times its kind, up to seven hundred times, except fasting, which is for Me, and I reward it}}
\hadithdefcmd{malik}{689}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ عَمِّهِ أَبِي سُهَيْلِ بْنِ مَالِكٍ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّهُ قَالَ إِذَا دَخَلَ رَمَضَانُ فُتِّحَتْ أَبْوَابُ الْجَنَّةِ وَغُلِّقَتْ أَبْوَابُ النَّارِ وَصُفِّدَتِ الشَّيَاطِينُ ‏.‏\hadithno{689}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Yahya related to me from Malik from his paternal uncle Abu Suhayl ibn Malik from his father that Abu Hurayra said, "When Ramadan comes the gates of the Garden are opened and the gates of the Fire are locked, and the shayatin are chained}}
